==> ejc-bfyjerp-api-3.0.0-20241226.071612-85-sources.jar: com/ejianc/business/asset/vo/PayReimburseDetailVO.java <==
package com.ejianc.business.asset.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 资产管理-费用报销子表
 * 
 * @author generator
 * 
 */
public class PayReimburseDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long payapplyId; // 付款申请单主键
    private Long feeType; // 费用类别
    private String feeTypeName; // 费用类别名称
    private BigDecimal feeTaxMny; // 费用金额
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date feeHappenDate; // 费用发生日期
    private Long subjectId; // 成本科目主键
    private String subjectName; // 成本科目名称
    private String feeMemo; // 备注
    

    public Long getPayapplyId() {
        return payapplyId;
    }

    public void setPayapplyId(Long payapplyId) {
        this.payapplyId = payapplyId;
    }
    @ReferSerialTransfer(referCode = "bfyj-categorydoc")
    public Long getFeeType() {
        return feeType;
    }
    @ReferDeserialTransfer
    public void setFeeType(Long feeType) {
        this.feeType = feeType;
    }
    public String getFeeTypeName() {
        return feeTypeName;
    }

    public void setFeeTypeName(String feeTypeName) {
        this.feeTypeName = feeTypeName;
    }
    public BigDecimal getFeeTaxMny() {
        return feeTaxMny;
    }

    public void setFeeTaxMny(BigDecimal feeTaxMny) {
        this.feeTaxMny = feeTaxMny;
    }
    public Date getFeeHappenDate() {
        return feeHappenDate;
    }

    public void setFeeHappenDate(Date feeHappenDate) {
        this.feeHappenDate = feeHappenDate;
    }
    public Long getSubjectId() {
        return subjectId;
    }

    public void setSubjectId(Long subjectId) {
        this.subjectId = subjectId;
    }
    public String getSubjectName() {
        return subjectName;
    }

    public void setSubjectName(String subjectName) {
        this.subjectName = subjectName;
    }
    public String getFeeMemo() {
        return feeMemo;
    }

    public void setFeeMemo(String feeMemo) {
        this.feeMemo = feeMemo;
    }
    
}

==> ejc-bfyjerp-api-3.0.0-20241227.014753-88-sources.jar: com/ejianc/business/asset/vo/PayReimburseDetailVO.java <==
package com.ejianc.business.asset.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 资产管理-费用报销子表
 * 
 * @author generator
 * 
 */
public class PayReimburseDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long payapplyId; // 付款申请单主键
    private Long feeType; // 费用类别
    private String feeTypeName; // 费用类别名称
    private BigDecimal feeTaxMny; // 费用金额
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date feeHappenDate; // 费用发生日期
    private Long subjectId; // 成本科目主键
    private String subjectName; // 成本科目名称
    private String feeMemo; // 备注
    private Integer feeTypeCostType; // 费用报销档案-成本费用类型

    public Integer getFeeTypeCostType() {
        return feeTypeCostType;
    }

    public void setFeeTypeCostType(Integer feeTypeCostType) {
        this.feeTypeCostType = feeTypeCostType;
    }

    public Long getPayapplyId() {
        return payapplyId;
    }

    public void setPayapplyId(Long payapplyId) {
        this.payapplyId = payapplyId;
    }
    @ReferSerialTransfer(referCode = "bfyj-categorydoc")
    public Long getFeeType() {
        return feeType;
    }
    @ReferDeserialTransfer
    public void setFeeType(Long feeType) {
        this.feeType = feeType;
    }
    public String getFeeTypeName() {
        return feeTypeName;
    }

    public void setFeeTypeName(String feeTypeName) {
        this.feeTypeName = feeTypeName;
    }
    public BigDecimal getFeeTaxMny() {
        return feeTaxMny;
    }

    public void setFeeTaxMny(BigDecimal feeTaxMny) {
        this.feeTaxMny = feeTaxMny;
    }
    public Date getFeeHappenDate() {
        return feeHappenDate;
    }

    public void setFeeHappenDate(Date feeHappenDate) {
        this.feeHappenDate = feeHappenDate;
    }
    public Long getSubjectId() {
        return subjectId;
    }

    public void setSubjectId(Long subjectId) {
        this.subjectId = subjectId;
    }
    public String getSubjectName() {
        return subjectName;
    }

    public void setSubjectName(String subjectName) {
        this.subjectName = subjectName;
    }
    public String getFeeMemo() {
        return feeMemo;
    }

    public void setFeeMemo(String feeMemo) {
        this.feeMemo = feeMemo;
    }
    
}
